==> openwebmail-2.10.tgz: htdocs/openwebmail/javascript/htmlarea.openwebmail/popups/es/htmlarea-lang.js <==
// I18N constants

// Translation Note
// 1. translate the left  side of fontname, font size and formatblock
// 2. translate the right side of tooltips

HTMLArea.I18N = {
	fontname: {
		"Arial":           'arial,helvetica,sans-serif',
		"Courier New":     'courier new,courier,monospace',
		"Georgia":         'georgia,times new roman,times,serif',
		"Tahoma":          'tahoma,arial,helvetica,sans-serif',
		"Times New Roman": 'times new roman,times,serif',
		"Verdana":         'verdana,arial,helvetica,sans-serif',
		"impact":          'impact',
		"WingDings":       'wingdings'
	},

	fontsize: {
		"1 (8 pt)":  "1",
		"2 (10 pt)": "2",
		"3 (12 pt)": "3",
		"4 (14 pt)": "4",
		"5 (18 pt)": "5",
		"6 (24 pt)": "6",
		"7 (36 pt)": "7"
	},

	formatblock: {
		"Encabezado 1": "h1",
		"Encabezado 2": "h2",
		"Encabezado 3": "h3",
		"Encabezado 4": "h4",
		"Encabezado 5": "h5",
		"Encabezado 6": "h6",
		"Normal": "p",
		"Direccin": "address",
		"Preformateado": "pre"
	},

	tooltips: {
		bold:           "Negrita",
		italic:         "Cursiva",
		underline:      "Subrayado",
		strikethrough:  "Tachado",
		subscript:      "Subndice",
		superscript:    "Supendice",
		justifyleft:    "Alinear a la izquierda",
		justifycenter:  "Centrar",
		justifyright:   "Alinear a la derecha",
		justifyfull:    "Justificar",
		orderedlist:    "Lista ordenada",
		unorderedlist:  "Vietas",
		outdent:        "Decrementar indentacin",
		indent:         "Incrementar indentacin",
		forecolor:      "Color de fuenta",
		backcolor:      "Color de fondo",
		horizontalrule: "Lnea horizontal",
		createlink:     "Insertar enlace",
		insertimage:    "Insertar imagen",
		insertsound:    "Insertar sonido",
		inserttable:    "Insertar tabla",
		htmlmode:       "Ver fuente HTML",
		popupeditor:    "Ampliar el editor",
		about:          "Acerca de...",
		help:           "Ayuda",
		textindicator:  "Estilo actual"
	}
};

==> openwebmail-2.32.tgz: htdocs/openwebmail/javascript/htmlarea.openwebmail/popups/es/htmlarea-lang.js <==
// I18N constants

// Translation Note
// 1. translate the left  side of fontname, font size and formatblock
// 2. translate the right side of tooltips

HTMLArea.I18N = {
	fontname: {
		"Arial":           'arial,helvetica,sans-serif',
		"Courier New":     'courier new,courier,monospace',
		"Georgia":         'georgia,times new roman,times,serif',
		"Tahoma":          'tahoma,arial,helvetica,sans-serif',
		"Times New Roman": 'times new roman,times,serif',
		"Verdana":         'verdana,arial,helvetica,sans-serif',
		"impact":          'impact',
		"WingDings":       'wingdings'
	},

	fontsize: {
		"1 (8 pt)":  "1",
		"2 (10 pt)": "2",
		"3 (12 pt)": "3",
		"4 (14 pt)": "4",
		"5 (18 pt)": "5",
		"6 (24 pt)": "6",
		"7 (36 pt)": "7"
	},

	formatblock: {
		"Encabezado 1": "h1",
		"Encabezado 2": "h2",
		"Encabezado 3": "h3",
		"Encabezado 4": "h4",
		"Encabezado 5": "h5",
		"Encabezado 6": "h6",
		"Normal": "p",
		"Direccin": "address",
		"Preformateado": "pre"
	},

	tooltips: {
		bold:           "Negrita",
		italic:         "Cursiva",
		underline:      "Subrayado",
		strikethrough:  "Tachado",
		subscript:      "Subndice",
		superscript:    "Supendice",
		justifyleft:    "Alinear a la izquierda",
		justifycenter:  "Centrar",
		justifyright:   "Alinear a la derecha",
		justifyfull:    "Justificar",
		insertorderedlist:    "Lista ordenada",
		insertunorderedlist:  "Vietas",
		outdent:        "Decrementar indentacin",
		indent:         "Incrementar indentacin",
		forecolor:      "Color de fuenta",
		hilitecolor:    "Color de fondo",
		horizontalrule: "Lnea horizontal",
		createlink:     "Insertar enlace",
		insertimage:    "Insertar imagen",
		insertsound:    "Insertar sonido",
		inserttable:    "Insertar tabla",
		htmlmode:       "Ver fuente HTML",
		popupeditor:    "Ampliar el editor",
		about:          "Acerca de...",
		showhelp:       "Ayuda",
		textindicator:  "Estilo actual",
		undo:           "Undoes your last action",
		redo:           "Redoes your last action",
		cut:            "Cut selection",
		copy:           "Copy selection",
		paste:          "Paste from clipboard"
	},

	buttons: {
		"ok":           "OK",
		"cancel":       "Cancel"
	},

	msg: {
		"Path":         "Path",
		"TEXT_MODE":    "You are in TEXT MODE.  Use the [<>] button to switch back to WYSIWIG."
	}
};
